@@ -83,7 +83,6 @@ app_init (Totem *totem, char **argv)
 		totem_action_exit (NULL);
 
 	totem->win = GTK_WIDGET (gtk_builder_get_object (totem->xml, "totem_main_window"));
-	gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (totem->win), TRUE);
 	g_object_bind_property (G_OBJECT (totem), "fullscreen",
 				G_OBJECT (totem->win), "show-menubar",
 				G_BINDING_INVERT_BOOLEAN);
@@ -208,6 +207,8 @@ app_command_line (GApplication             *app,
 	if (startup_called != FALSE) {
 		app_init (totem, argv);
 
+		gdk_notify_startup_complete ();
+
 		/* Don't add files again through totem_options_process_for_server() */
 		g_strfreev (optionstate.filenames);
 		optionstate.filenames = NULL;
